import subprocess
import pytest
def run_test_script(name):
    # os.chdir()
    p=subprocess.Popen(["python","tests/{}".format(name)])
    (stdout, stderr) = p.communicate()
    assert p.returncode ==0, stderr
    # print(stderr)

names=["demo.py",
"play_gym.py",
"play_gym_pend.py",
"play_gym_atari.py",
"play_gym_reach.py",]


@pytest.mark.parametrize("name", names)
def test_script(name):
    print(name)
    run_test_script(name)


import gym
from rl_helper import envhelper

if __name__=="__main__":

    env = gym.make('CartPole-v1')
    print(env.metadata)
    gym_env_helper=envhelper()

    frames=[]
    for episode in range(2): 
        obs = env.reset()
        for step in range(30):
            action = env.action_space.sample()  # or given a custom model, action = policy(observation)
            nobs, reward, done, info = env.step(action)
            if done:
                break
            # env.render()
            gym_env_helper.recording(env)
        env.close()

    gym_env_helper.save_gif(times=3)


print("please install mujoco-py")
# import gym
# from rl_helper import envhelper
# if __name__=="__main__":

#     env = gym.make('FetchReach-v1')
#     print(env.metadata)
#     gym_env_helper=envhelper()

#     frames=[]
#     for episode in range(2): 
#         obs = env.reset()
#         for step in range(30):
#             action = env.action_space.sample()  # or given a custom model, action = policy(observation)
#             nobs, reward, done, info = env.step(action)
#             if done:
#                 break
#             gym_env_helper.recording(env)
#         env.close()

#     gym_env_helper.save_gif(times=3)


from setuptools import find_packages, setup


# Required dependencies
required = [
    "gym","pytest","matplotlib","pyvirtualdisplay"
]


setup(
    name='rl_helper',
    version="0.1.1",
    author="cywgoog@gmail.com",
    packages=find_packages("rl_helper"),
    include_package_data=True,
    install_requires=required
)